@@ -29,6 +29,9 @@ simNmixSpatial <- function(nsurveys = 3, mean.lambda = exp(2), beta = c(2, -2),
 BerneseOberland <- NULL # otherwise "no visible binding for global variable 'BerneseOberland'" when checked
 data(BerneseOberland, envir = environment())
 
+# Load raster package
+checkNamespace("raster")
+
 # Simulate spatial random field
 set.seed(seeds[1])
 s <- simExpCorrRF(variance = variance.RF, theta = theta.RF, show.plots=show.plots)
